==> docfbe_2_3_35_62.zip: docfbe_2_2_35_62/source/TCFbEColumnColumnCachedTable.cpp <==
/*
    TCFbEColumnColumnCachedTable.cpp    November 29, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbEColumnColumnCachedTable.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^iLbV쐬
__fastcall TCFbEColumnColumnCachedTable::TCFbEColumnColumnCachedTable(void)
    : TCFbECachedTable()
{
}

//---------------------------------------------------------------------------
// w肳ꂽse[u쐬
__fastcall TCFbEColumnColumnCachedTable::TCFbEColumnColumnCachedTable(TStringList* RowLabelList, TStringList* ColumnLabelList)
    : TCFbECachedTable(ColumnLabelList, ColumnLabelList)
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbEColumnColumnCachedTable::~TCFbEColumnColumnCachedTable()
{
}

//---------------------------------------------------------------------------
// ȉCprotected method
//---------------------------------------------------------------------------
// eLbṼZXVꂽ
void __fastcall TCFbEColumnColumnCachedTable::ParentCellIsUpdated(int RowIndex, int ColumnIndex)
{
    if (!this->FIsLinkedToParent) {
        return;
    }

    for (int i = 0; i < this->GetNumberOfRows(); i++) {
        this->UnableElementByIndex(i, ColumnIndex);
        this->UnableElementByIndex(ColumnIndex, i);
    }
}

//---------------------------------------------------------------------------
// eLbV̍sǉꂽ
int __fastcall  TCFbEColumnColumnCachedTable::ParentAddRow(AnsiString RowLabel)
{
    return -1;
}

//---------------------------------------------------------------------------
// eLbV̗񂪒ǉꂽ
int __fastcall  TCFbEColumnColumnCachedTable::ParentAddColumn(AnsiString ColumnLabel)
{
    this->AddRow(ColumnLabel);
    return this->AddColumn(ColumnLabel);
}

//---------------------------------------------------------------------------
// eLbV̍s폜ꂽ
void __fastcall TCFbEColumnColumnCachedTable::ParentDeleteRowByIndex(int TargetRowIndex)
{
    return;
}

//---------------------------------------------------------------------------
// eLbV̗񂪍폜ꂽ
void __fastcall TCFbEColumnColumnCachedTable::ParentDeleteColumnByIndex(int TargetColumnIndex)
{
    this->DeleteRowByIndex(TargetColumnIndex);
    this->DeleteColumnByIndex(TargetColumnIndex);
}

//---------------------------------------------------------------------------
// g̃N[쐬
TCFbECachedTable* __fastcall TCFbEColumnColumnCachedTable::CreateClone(void)
{
    TCFbEColumnColumnCachedTable* Clone = new TCFbEColumnColumnCachedTable();
    Clone->Assign(this);
    return Clone;       
}

//---------------------------------------------------------------------------
// g̍sƗ񂪓ւN[쐬
TCFbECachedTable* __fastcall TCFbEColumnColumnCachedTable::CreateRotatedClone(void)
{
    TCFbEColumnColumnCachedTable* Clone = new TCFbEColumnColumnCachedTable();
    Clone->RotatedAssign(this);
    return Clone;
}

//---------------------------------------------------------------------------

==> docfbe_2_3_37_64.zip: docfbe_2_3_37_64/source/TCFbEColumnColumnCachedTable.cpp <==
/*
    TCFbEColumnColumnCachedTable.cpp    November 29, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbEColumnColumnCachedTable.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^iLbV쐬
__fastcall TCFbEColumnColumnCachedTable::TCFbEColumnColumnCachedTable(void)
    : TCFbECachedTable()
{
}

//---------------------------------------------------------------------------
// w肳ꂽse[u쐬
__fastcall TCFbEColumnColumnCachedTable::TCFbEColumnColumnCachedTable(TStringList* RowLabelList, TStringList* ColumnLabelList)
    : TCFbECachedTable(ColumnLabelList, ColumnLabelList)
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbEColumnColumnCachedTable::~TCFbEColumnColumnCachedTable()
{
}

//---------------------------------------------------------------------------
// ȉCprotected method
//---------------------------------------------------------------------------
// eLbṼZXVꂽ
void __fastcall TCFbEColumnColumnCachedTable::ParentCellIsUpdated(int RowIndex, int ColumnIndex)
{
    if (!this->FIsLinkedToParent) {
        return;
    }

    for (int i = 0; i < this->GetNumberOfRows(); i++) {
        this->UnableElementByIndex(i, ColumnIndex);
        this->UnableElementByIndex(ColumnIndex, i);
    }
}

//---------------------------------------------------------------------------
// eLbV̍sǉꂽ
int __fastcall  TCFbEColumnColumnCachedTable::ParentAddRow(const char* RowLabel)
{
    return -1;
}

//---------------------------------------------------------------------------
// eLbV̗񂪒ǉꂽ
int __fastcall  TCFbEColumnColumnCachedTable::ParentAddColumn(const char* ColumnLabel)
{
    this->AddRow(ColumnLabel);
    return this->AddColumn(ColumnLabel);
}

//---------------------------------------------------------------------------
// eLbV̍s폜ꂽ
void __fastcall TCFbEColumnColumnCachedTable::ParentDeleteRowByIndex(int TargetRowIndex)
{
    return;
}

//---------------------------------------------------------------------------
// eLbV̗񂪍폜ꂽ
void __fastcall TCFbEColumnColumnCachedTable::ParentDeleteColumnByIndex(int TargetColumnIndex)
{
    this->DeleteRowByIndex(TargetColumnIndex);
    this->DeleteColumnByIndex(TargetColumnIndex);
}

//---------------------------------------------------------------------------
// g̃N[쐬
TCFbECachedTable* __fastcall TCFbEColumnColumnCachedTable::CreateClone(void)
{
    TCFbEColumnColumnCachedTable* Clone = new TCFbEColumnColumnCachedTable();
    Clone->Assign(this);
    return Clone;       
}

//---------------------------------------------------------------------------
// g̍sƗ񂪓ւN[쐬
TCFbECachedTable* __fastcall TCFbEColumnColumnCachedTable::CreateRotatedClone(void)
{
    TCFbEColumnColumnCachedTable* Clone = new TCFbEColumnColumnCachedTable();
    Clone->RotatedAssign(this);
    return Clone;
}

//---------------------------------------------------------------------------
